<?php
require_once 'vendor/autoload.php';
use ICal\ICal;
$DATE_FORMAT = 'd.m.Y H:i';
$state_map = array(
	'closed' => (object) array(
		'state_string' => 'Das Dorf ist gerade <em>geschlossen</em>.',
		'svg' => 'lock',
		'color' => 'red',
	),
	'maybe_open' => (object) array(
		'state_string' => 'Das Dorf ist gerade <em>vielleicht geöffnet</em>: </p><p>Der Clubraum ist offen, aber es findet keine Veranstaltung statt.</p><p>
		Der Status kann sich also kurzfristig ändern.',
		'svg' => 'done',
		'color' => 'brown',
	),
	'open' => (object) array(
		'state_string' => 'Das Dorf ist gerade <em>geöffnet</em>.</p><p>
		Komm gerne vorbei.',
		'svg' => 'done',
		'color' => 'green',
	),
	'private' => (object) array(
		'state_string' => 'Das Dorf ist gerade <em>privat</em>: </p><p>Es sind Leute da, aber der Clubraum ist nicht geöffnet.</p><p>
		Komm gerne vorbei (aber frag lieber vorher, wie lange noch Leute da sind).',
		'svg' => 'lock',
		'color' => '#fdd835',
	),
	'unknown' => (object) array(
		'state_string' => 'Der Status vom Dorf ist gerade <em>unbekannt</em>',
		'svg' => 'warning',
		'color' => 'orange',
	),
	'error' => (object) array(
		'state_string' => 'Der Server konnte den Status vom Dorf nicht abrufen.',
		'svg' => 'error',
		'color' => 'blue',
	),
);
$hash_to_state = array(
	'bff0167ed8aba031c49122ef4046cf1b' => 'closed',
	'd8ec899c69283bc775952a767db9d5f5' => 'maybe_open',
	'2c2672c641425e5b2acd6ee74f39ae60' => 'open',
	'66aece8ae27ffd3a656d42005fa3efbd' => 'private',
	'86c75c0ad413b06ff8291673162d0b64' => 'unknown',
	'0' => 'error',
);

$img = file_get_contents('https://chaosdorf.de/raumstatus/status.png');
$hash = md5($img);
$state = $hash_to_state[$hash];
	$ical = new ICal(false, array(
		'defaultSpan' => 2,
		'defaultTimeZone' => 'Europe/Berlin',
		'defaultWeekStart' => 'MO',
		'filterDaysBefore' => '1',
	));
$ical->initUrl('https://chaosdorf.de/~derf/cccd_all.ics', $acceptLanguage = 'de');
$events = $ical->eventsFromInterval('2 week');
$first_event = $events[0];
$events = array_slice($events, 1);
$locale = locale_accept_from_http($_SERVER['HTTP_ACCEPT_LANGUAGE']);
if ($locale !== null){
	setlocale(LC_TIME, $locale);
}
$v = file_get_contents('/media/sg/dorf.jetzt_visitors');
?>
<!DOCTYPE html>
<html lang="de">
<head>
	<title>Was geht im Dorf.jetzt?</title>
	<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no" />
	<link rel="stylesheet" href="assets/css/bootstrap.min.css" integrity="sha384-Vkoo8x4CGsO3+Hhxv8T/Q5PaXtkKtu6ug5TOeNV6gBiFeWPGFN9MuhOf23Q9Ifjh" crossorigin="anonymous">
	<link href="assets/font/Material-Icons.css" rel="stylesheet">
	<meta charset="UTF-8" />
</head>
<body>
	<div class="container">
		<nav class="navbar">	
			<h1 class="text-center">Was geht im Dorf.jetzt?</h1><hr />
		</nav>
			<div class="card mb-3 text-center">
				<div class="card-body">
					<h5 class="card-title">Türstatus</h5>
					<i class="material-icons" id="state-icn" style="color:<?= $state_map[$state]->color ?>;font-size:16rem;"><?= $state_map[$state]->svg ?></i> 
					<p class="card-text"><?= $state_map[$state]->state_string ?></p>
						<div class="btn-wrapper">
							<a href="https://wiki.chaosdorf.de/Raumstatus" class="btn btn-lg btn-block btn-primary">What's this?</a>
						</div>
				
				</div>
			</div>
			<div class="card mb-3 text-center">
				<div class="card-body">
					<h5 class="card-title">Events</h5>
					<h6 class="card-subtitle mb-2 text-muted">Nächste Veranstaltung</h6>
					<p class="card-text">
						<h5 class="font-weight-bold"><?= htmlspecialchars($first_event->summary, ENT_QUOTES, 'UTF-8') ?></h5>
						<span class="font-weight-normal"><?= $ical->iCalDateToDateTime($first_event->dtstart_array[3])->format($DATE_FORMAT) ?></span>
					</p>
					<h5 class="card-title">Danach:</h5>
					<table class="table">
						<tbody>
						<?php foreach ($events as $event) : ?>
							<tr>
								<th scope="row"><?php 
								$startdate_loop = $ical->iCalDateToDateTime($event->dtstart_array[3]);
								$startdate_str = $startdate_loop->format($DATE_FORMAT);
								$interval_loop = new DateInterval($event->duration);
								if ($interval_loop->d != 0 || $interval_loop->h >= 24){
									$enddate_str = $startdate_loop->add($interval_loop)->format($DATE_FORMAT);
								}else{
									$enddate_str = $startdate_loop->add($interval_loop)->format('H:i');
								}
								echo($startdate_str . ' &ndash; ' . $enddate_str); ?></th>
								<td><?= htmlspecialchars($event->summary) ?></td>
							</tr>
						<?php endforeach ?>
						</tbody>
					</table>
						<a href="https://wiki.chaosdorf.de/Chaosdorf_Wiki:Current_events" class="btn btn-lg btn-block btn-primary">Event-Kalender</a>
				</div>
			</div>
		</div>
	<footer class="page-footer font-small text-center">
		<div>
		Look at the code <a href="https://git.iwonder.name/iwonder/dorf.jetzt">here</a>
		</div>
		<div>
		Report issues to <a href="mailto:help@dorf.jetzt">help@dorf.jetzt</a>
		</div>
		<div>You are visitor #<?= $v ?>
	</footer>
	<script src="assets/js/jquery-3.4.1.slim.min.js" integrity="sha384-J6qa4849blE2+poT4WnyKhv5vZF5SrPo0iEjwBvKU7imGFAV0wwj1yYfoRSJoZ+n" crossorigin="anonymous"></script>
	<script src="https://cdn.jsdelivr.net/npm/popper.js@1.16.0/dist/umd/popper.min.js" integrity="sha384-Q6E9RHvbIyZFJoft+2mJbHaEWldlvI9IOYy5n3zV9zzTtmI3UksdQRVvoxMfooAo" crossorigin="anonymous"></script>
	<script src="assets/js/bootstrap.min.js" integrity="sha384-wfSDF2E50Y2D1uUdj0O3uMBJnjuUD4Ih7YwaYd1iqfktj0Uod8GCExl3Og8ifwB6" crossorigin="anonymous"></script>
</body>
</html>
<?php
if(!$v) $v=0;
$v++;
file_put_contents('/media/sg/dorf.jetzt_visitors', $v);
